[SCM] Samba Shared Repository - branch master updated

Andrew Bartlett abartlet at samba.org
Tue May 7 01:46:02 UTC 2019


The branch, master has been updated
       via  1d8c4c64b12 gitlab-ci: Enable building on CentOS7
       via  86d4836919e bootstrap: Install correct python modules on CentOS7
       via  3c47066e067 bootstrap: Move to python 3.6 on CentOS
       via  05791f40a6e bootstrap: Make sure that the python3 interpreter is installed
       via  4607ed73354 bootstrap: Fix yum commands
       via  1b9cd2acda3 waf: Also check for gnutls_privkey_export_x509()
      from  193b44466ba nsswitch pam_winbind: Fix Asan use after free

https://git.samba.org/?p=samba.git;a=shortlog;h=master


- Log -----------------------------------------------------------------
commit 1d8c4c64b123d287c13a8be4101fa5575fd73e85
Author: Andreas Schneider <asn at samba.org>
Date:   Tue Apr 30 08:34:00 2019 +0200

    gitlab-ci: Enable building on CentOS7
    
    Signed-off-by: Andreas Schneider <asn at samba.org>
    Reviewed-by: Andrew Bartlett <abartlet at samba.org>
    
    Autobuild-User(master): Andrew Bartlett <abartlet at samba.org>
    Autobuild-Date(master): Tue May  7 01:45:37 UTC 2019 on sn-devel-184

commit 86d4836919e29c0bdf927658df641811247534c6
Author: Andreas Schneider <asn at samba.org>
Date:   Tue Apr 30 12:20:34 2019 +0200

    bootstrap: Install correct python modules on CentOS7
    
    Signed-off-by: Andreas Schneider <asn at samba.org>
    Reviewed-by: Andrew Bartlett <abartlet at samba.org>

commit 3c47066e067dd23e46435e5b3f8c8801a6d81fb7
Author: Andreas Schneider <asn at samba.org>
Date:   Mon May 6 10:33:01 2019 +0200

    bootstrap: Move to python 3.6 on CentOS
    
    Signed-off-by: Andreas Schneider <asn at samba.org>
    Reviewed-by: Andrew Bartlett <abartlet at samba.org>

commit 05791f40a6e78e628ec4ab2fb0e13b2c7fbb1b78
Author: Andreas Schneider <asn at samba.org>
Date:   Tue Apr 30 09:48:39 2019 +0200

    bootstrap: Make sure that the python3 interpreter is installed
    
    We need it for waf ;-)
    
    Signed-off-by: Andreas Schneider <asn at samba.org>
    Reviewed-by: Andrew Bartlett <abartlet at samba.org>

commit 4607ed73354716367e71f575d18bd8f5ba8e926d
Author: Andreas Schneider <asn at samba.org>
Date:   Tue Apr 30 08:33:15 2019 +0200

    bootstrap: Fix yum commands
    
    Signed-off-by: Andreas Schneider <asn at samba.org>
    Reviewed-by: Andrew Bartlett <abartlet at samba.org>

commit 1b9cd2acda393577c0e9c2ef908c520b3d7ca6f7
Author: Andreas Schneider <asn at samba.org>
Date:   Mon May 6 11:12:54 2019 +0200

    waf: Also check for gnutls_privkey_export_x509()
    
    Signed-off-by: Andreas Schneider <asn at samba.org>
    Reviewed-by: Andrew Bartlett <abartlet at samba.org>

-----------------------------------------------------------------------

Summary of changes:
 .gitlab-ci.yml                                     | 10 ++++++++-
 bootstrap/.gitlab-ci.yml                           |  5 ++++-
 bootstrap/config.py                                | 26 ++++++++++++++++------
 bootstrap/generated-dists/centos6/bootstrap.sh     | 17 +++++++++-----
 bootstrap/generated-dists/centos6/packages.yml     |  3 ++-
 bootstrap/generated-dists/centos7/bootstrap.sh     | 23 +++++++++++--------
 bootstrap/generated-dists/centos7/packages.yml     |  9 ++++----
 bootstrap/generated-dists/debian7/bootstrap.sh     |  1 +
 bootstrap/generated-dists/debian7/packages.yml     |  1 +
 bootstrap/generated-dists/debian8/bootstrap.sh     |  1 +
 bootstrap/generated-dists/debian8/packages.yml     |  1 +
 bootstrap/generated-dists/debian9/bootstrap.sh     |  1 +
 bootstrap/generated-dists/debian9/packages.yml     |  1 +
 bootstrap/generated-dists/fedora28/bootstrap.sh    |  1 +
 bootstrap/generated-dists/fedora28/packages.yml    |  1 +
 bootstrap/generated-dists/fedora29/bootstrap.sh    |  1 +
 bootstrap/generated-dists/fedora29/packages.yml    |  1 +
 bootstrap/generated-dists/opensuse150/bootstrap.sh |  1 +
 bootstrap/generated-dists/opensuse150/packages.yml |  1 +
 bootstrap/generated-dists/ubuntu1404/bootstrap.sh  |  1 +
 bootstrap/generated-dists/ubuntu1404/packages.yml  |  1 +
 bootstrap/generated-dists/ubuntu1604/bootstrap.sh  |  1 +
 bootstrap/generated-dists/ubuntu1604/packages.yml  |  1 +
 bootstrap/generated-dists/ubuntu1804/bootstrap.sh  |  1 +
 bootstrap/generated-dists/ubuntu1804/packages.yml  |  1 +
 bootstrap/sha1sum.txt                              |  2 +-
 source4/rpc_server/wscript_build                   |  3 ++-
 source4/torture/wscript_build                      |  3 ++-
 wscript_configure_system_gnutls                    |  3 +++
 29 files changed, 90 insertions(+), 32 deletions(-)


Changeset truncated at 500 lines:

diff --git a/.gitlab-ci.yml b/.gitlab-ci.yml
index 8b9d0cb69be..3d01f8fc376 100644
--- a/.gitlab-ci.yml
+++ b/.gitlab-ci.yml
@@ -19,7 +19,7 @@ variables:
   # Set this to the contents of bootstrap/sha1sum.txt
   # which is generated by bootstrap/template.py --render
   #
-  SAMBA_CI_CONTAINER_TAG: 2be76362af215af6842e884abd5246dd9b50c283
+  SAMBA_CI_CONTAINER_TAG: 93278680b4e7086c0bec11a58bc3533f9971c08e
   # We use the ubuntu1804 image as default as
   # it matches what we have on sn-devel-184.
   SAMBA_CI_CONTAINER_IMAGE: ubuntu1804
@@ -33,6 +33,7 @@ variables:
   SAMBA_CI_CONTAINER_IMAGE_debian9: ${SAMBA_CI_CONTAINER_REGISTRY}/samba-ci-debian9:${SAMBA_CI_CONTAINER_TAG}
   SAMBA_CI_CONTAINER_IMAGE_opensuse150: ${SAMBA_CI_CONTAINER_REGISTRY}/samba-ci-opensuse150:${SAMBA_CI_CONTAINER_TAG}
   SAMBA_CI_CONTAINER_IMAGE_fedora29: ${SAMBA_CI_CONTAINER_REGISTRY}/samba-ci-fedora29:${SAMBA_CI_CONTAINER_TAG}
+  SAMBA_CI_CONTAINER_IMAGE_centos7: ${SAMBA_CI_CONTAINER_REGISTRY}/samba-ci-centos7:${SAMBA_CI_CONTAINER_TAG}
 
 include:
   # The image creation details are specified in a separate file
@@ -200,6 +201,13 @@ opensuse150-samba-o3:
   extends: .samba-o3-template
   image: $SAMBA_CI_CONTAINER_IMAGE_opensuse150
 
+centos7-samba-o3:
+  extends: .samba-o3-template
+  image: $SAMBA_CI_CONTAINER_IMAGE_centos7
+  variables:
+    # Git on CentOS doesn't support shallow git cloning
+    GIT_DEPTH: ""
+
 fedora29-samba-o3:
   extends: .samba-o3-template
   image: $SAMBA_CI_CONTAINER_IMAGE_fedora29
diff --git a/bootstrap/.gitlab-ci.yml b/bootstrap/.gitlab-ci.yml
index ac255771953..1b07c54afd2 100644
--- a/bootstrap/.gitlab-ci.yml
+++ b/bootstrap/.gitlab-ci.yml
@@ -107,7 +107,10 @@ fedora28:
   extends: .build_image_template_force_broken
 
 centos7:
-  extends: .build_image_template_force_broken
+  extends: .build_image_template
+  variables:
+    # Shallow copies are not supported by git on CentOS7
+    GIT_DEPTH: ""
 
 centos6:
   extends: .build_image_template_force_broken
diff --git a/bootstrap/generated-dists/centos6/bootstrap.sh b/bootstrap/generated-dists/centos6/bootstrap.sh
index 521d571d1f6..203386bf447 100755
--- a/bootstrap/generated-dists/centos6/bootstrap.sh
+++ b/bootstrap/generated-dists/centos6/bootstrap.sh
@@ -7,11 +7,11 @@
 
 set -xueo pipefail
 
-yum -y -q update
-yum -y -q install epel-release
-yum -y -q update
+yum update -y
+yum install -y epel-release
+yum update -y
 
-yum -y -q --verbose install \
+yum install -y \
     "@Development Tools" \
     acl \
     attr \
@@ -87,7 +87,8 @@ yum -y -q --verbose install \
     python3-crypto \
     python3-dns \
     python3-markdown \
-    python34-devel \
+    python36 \
+    python36-devel \
     quota-devel \
     readline-devel \
     redhat-lsb \
@@ -104,4 +105,8 @@ yum -y -q --verbose install \
     yum-utils \
     zlib-devel
 
-yum clean all
\ No newline at end of file
+yum clean all
+
+if [ ! -f /usr/bin/python3 ]; then
+    ln -sf /usr/bin/python3.6 /usr/bin/python3
+fi
\ No newline at end of file
diff --git a/bootstrap/generated-dists/centos6/packages.yml b/bootstrap/generated-dists/centos6/packages.yml
index c9aef4d64ee..98a89a844f9 100644
--- a/bootstrap/generated-dists/centos6/packages.yml
+++ b/bootstrap/generated-dists/centos6/packages.yml
@@ -75,7 +75,8 @@ packages:
   - python3-crypto
   - python3-dns
   - python3-markdown
-  - python34-devel
+  - python36
+  - python36-devel
   - quota-devel
   - readline-devel
   - redhat-lsb
diff --git a/bootstrap/generated-dists/centos7/bootstrap.sh b/bootstrap/generated-dists/centos7/bootstrap.sh
index fa1e49836f3..c3ccc4bb0b9 100755
--- a/bootstrap/generated-dists/centos7/bootstrap.sh
+++ b/bootstrap/generated-dists/centos7/bootstrap.sh
@@ -7,11 +7,11 @@
 
 set -xueo pipefail
 
-yum -y -q update
-yum -y -q install epel-release
-yum -y -q update
+yum update -y
+yum install -y epel-release
+yum update -y
 
-yum -y -q --verbose install \
+yum install -y \
     "@Development Tools" \
     acl \
     attr \
@@ -84,10 +84,11 @@ yum -y -q --verbose install \
     python-devel \
     python-dns \
     python-markdown \
-    python3-crypto \
-    python3-dns \
-    python3-markdown \
-    python34-devel \
+    python36 \
+    python36-crypto \
+    python36-devel \
+    python36-dns \
+    python36-markdown \
     quota-devel \
     readline-devel \
     redhat-lsb \
@@ -104,4 +105,8 @@ yum -y -q --verbose install \
     yum-utils \
     zlib-devel
 
-yum clean all
\ No newline at end of file
+yum clean all
+
+if [ ! -f /usr/bin/python3 ]; then
+    ln -sf /usr/bin/python3.6 /usr/bin/python3
+fi
\ No newline at end of file
diff --git a/bootstrap/generated-dists/centos7/packages.yml b/bootstrap/generated-dists/centos7/packages.yml
index 2dd4fb68265..40c5513d72c 100644
--- a/bootstrap/generated-dists/centos7/packages.yml
+++ b/bootstrap/generated-dists/centos7/packages.yml
@@ -72,10 +72,11 @@ packages:
   - python-devel
   - python-dns
   - python-markdown
-  - python3-crypto
-  - python3-dns
-  - python3-markdown
-  - python34-devel
+  - python36
+  - python36-crypto
+  - python36-devel
+  - python36-dns
+  - python36-markdown
   - quota-devel
   - readline-devel
   - redhat-lsb
diff --git a/bootstrap/generated-dists/debian7/bootstrap.sh b/bootstrap/generated-dists/debian7/bootstrap.sh
index 6141efc3a2b..f506af4c616 100755
--- a/bootstrap/generated-dists/debian7/bootstrap.sh
+++ b/bootstrap/generated-dists/debian7/bootstrap.sh
@@ -84,6 +84,7 @@ apt-get -y install \
     python-iso8601 \
     python-markdown \
     python-pexpect \
+    python3 \
     python3-crypto \
     python3-dbg \
     python3-dev \
diff --git a/bootstrap/generated-dists/debian7/packages.yml b/bootstrap/generated-dists/debian7/packages.yml
index 9cb9b2df5b9..645df5a0692 100644
--- a/bootstrap/generated-dists/debian7/packages.yml
+++ b/bootstrap/generated-dists/debian7/packages.yml
@@ -73,6 +73,7 @@ packages:
   - python-iso8601
   - python-markdown
   - python-pexpect
+  - python3
   - python3-crypto
   - python3-dbg
   - python3-dev
diff --git a/bootstrap/generated-dists/debian8/bootstrap.sh b/bootstrap/generated-dists/debian8/bootstrap.sh
index 0388a1134d4..214574fed08 100755
--- a/bootstrap/generated-dists/debian8/bootstrap.sh
+++ b/bootstrap/generated-dists/debian8/bootstrap.sh
@@ -87,6 +87,7 @@ apt-get -y install \
     python-iso8601 \
     python-markdown \
     python-pexpect \
+    python3 \
     python3-crypto \
     python3-dbg \
     python3-dev \
diff --git a/bootstrap/generated-dists/debian8/packages.yml b/bootstrap/generated-dists/debian8/packages.yml
index f7e9ec61fe3..f5574edb1b9 100644
--- a/bootstrap/generated-dists/debian8/packages.yml
+++ b/bootstrap/generated-dists/debian8/packages.yml
@@ -76,6 +76,7 @@ packages:
   - python-iso8601
   - python-markdown
   - python-pexpect
+  - python3
   - python3-crypto
   - python3-dbg
   - python3-dev
diff --git a/bootstrap/generated-dists/debian9/bootstrap.sh b/bootstrap/generated-dists/debian9/bootstrap.sh
index 5576c455ce7..9349fd2fa5b 100755
--- a/bootstrap/generated-dists/debian9/bootstrap.sh
+++ b/bootstrap/generated-dists/debian9/bootstrap.sh
@@ -87,6 +87,7 @@ apt-get -y install \
     python-iso8601 \
     python-markdown \
     python-pexpect \
+    python3 \
     python3-crypto \
     python3-dbg \
     python3-dev \
diff --git a/bootstrap/generated-dists/debian9/packages.yml b/bootstrap/generated-dists/debian9/packages.yml
index 03d9f4759a5..d46d33f1e57 100644
--- a/bootstrap/generated-dists/debian9/packages.yml
+++ b/bootstrap/generated-dists/debian9/packages.yml
@@ -76,6 +76,7 @@ packages:
   - python-iso8601
   - python-markdown
   - python-pexpect
+  - python3
   - python3-crypto
   - python3-dbg
   - python3-dev
diff --git a/bootstrap/generated-dists/fedora28/bootstrap.sh b/bootstrap/generated-dists/fedora28/bootstrap.sh
index e2e4ee99803..2c365247e6a 100755
--- a/bootstrap/generated-dists/fedora28/bootstrap.sh
+++ b/bootstrap/generated-dists/fedora28/bootstrap.sh
@@ -87,6 +87,7 @@ dnf install -y \
     python-dns \
     python-markdown \
     python2-gpg \
+    python3 \
     python3-crypto \
     python3-devel \
     python3-dns \
diff --git a/bootstrap/generated-dists/fedora28/packages.yml b/bootstrap/generated-dists/fedora28/packages.yml
index e20a8764a6b..2961e4c0a50 100644
--- a/bootstrap/generated-dists/fedora28/packages.yml
+++ b/bootstrap/generated-dists/fedora28/packages.yml
@@ -76,6 +76,7 @@ packages:
   - python-dns
   - python-markdown
   - python2-gpg
+  - python3
   - python3-crypto
   - python3-devel
   - python3-dns
diff --git a/bootstrap/generated-dists/fedora29/bootstrap.sh b/bootstrap/generated-dists/fedora29/bootstrap.sh
index e2e4ee99803..2c365247e6a 100755
--- a/bootstrap/generated-dists/fedora29/bootstrap.sh
+++ b/bootstrap/generated-dists/fedora29/bootstrap.sh
@@ -87,6 +87,7 @@ dnf install -y \
     python-dns \
     python-markdown \
     python2-gpg \
+    python3 \
     python3-crypto \
     python3-devel \
     python3-dns \
diff --git a/bootstrap/generated-dists/fedora29/packages.yml b/bootstrap/generated-dists/fedora29/packages.yml
index e20a8764a6b..2961e4c0a50 100644
--- a/bootstrap/generated-dists/fedora29/packages.yml
+++ b/bootstrap/generated-dists/fedora29/packages.yml
@@ -76,6 +76,7 @@ packages:
   - python-dns
   - python-markdown
   - python2-gpg
+  - python3
   - python3-crypto
   - python3-devel
   - python3-dns
diff --git a/bootstrap/generated-dists/opensuse150/bootstrap.sh b/bootstrap/generated-dists/opensuse150/bootstrap.sh
index 41506f9c67e..4bf205e5ffb 100755
--- a/bootstrap/generated-dists/opensuse150/bootstrap.sh
+++ b/bootstrap/generated-dists/opensuse150/bootstrap.sh
@@ -84,6 +84,7 @@ zypper --non-interactive install \
     python2-dnspython \
     python2-gpg \
     python2-semanage \
+    python3 \
     python3-Markdown \
     python3-devel \
     python3-dnspython \
diff --git a/bootstrap/generated-dists/opensuse150/packages.yml b/bootstrap/generated-dists/opensuse150/packages.yml
index 66c59e4ee2a..8183e89804e 100644
--- a/bootstrap/generated-dists/opensuse150/packages.yml
+++ b/bootstrap/generated-dists/opensuse150/packages.yml
@@ -72,6 +72,7 @@ packages:
   - python2-dnspython
   - python2-gpg
   - python2-semanage
+  - python3
   - python3-Markdown
   - python3-devel
   - python3-dnspython
diff --git a/bootstrap/generated-dists/ubuntu1404/bootstrap.sh b/bootstrap/generated-dists/ubuntu1404/bootstrap.sh
index b391f6ae225..ba193207c44 100755
--- a/bootstrap/generated-dists/ubuntu1404/bootstrap.sh
+++ b/bootstrap/generated-dists/ubuntu1404/bootstrap.sh
@@ -85,6 +85,7 @@ apt-get -y install \
     python-iso8601 \
     python-markdown \
     python-pexpect \
+    python3 \
     python3-crypto \
     python3-dbg \
     python3-dev \
diff --git a/bootstrap/generated-dists/ubuntu1404/packages.yml b/bootstrap/generated-dists/ubuntu1404/packages.yml
index 1a69db83823..477fc4fb090 100644
--- a/bootstrap/generated-dists/ubuntu1404/packages.yml
+++ b/bootstrap/generated-dists/ubuntu1404/packages.yml
@@ -74,6 +74,7 @@ packages:
   - python-iso8601
   - python-markdown
   - python-pexpect
+  - python3
   - python3-crypto
   - python3-dbg
   - python3-dev
diff --git a/bootstrap/generated-dists/ubuntu1604/bootstrap.sh b/bootstrap/generated-dists/ubuntu1604/bootstrap.sh
index 71d284a3d54..6a3e43f3dab 100755
--- a/bootstrap/generated-dists/ubuntu1604/bootstrap.sh
+++ b/bootstrap/generated-dists/ubuntu1604/bootstrap.sh
@@ -86,6 +86,7 @@ apt-get -y install \
     python-iso8601 \
     python-markdown \
     python-pexpect \
+    python3 \
     python3-crypto \
     python3-dbg \
     python3-dev \
diff --git a/bootstrap/generated-dists/ubuntu1604/packages.yml b/bootstrap/generated-dists/ubuntu1604/packages.yml
index 2b0011c2c1f..653add38bfb 100644
--- a/bootstrap/generated-dists/ubuntu1604/packages.yml
+++ b/bootstrap/generated-dists/ubuntu1604/packages.yml
@@ -75,6 +75,7 @@ packages:
   - python-iso8601
   - python-markdown
   - python-pexpect
+  - python3
   - python3-crypto
   - python3-dbg
   - python3-dev
diff --git a/bootstrap/generated-dists/ubuntu1804/bootstrap.sh b/bootstrap/generated-dists/ubuntu1804/bootstrap.sh
index b019db6db7a..6149a2b27ea 100755
--- a/bootstrap/generated-dists/ubuntu1804/bootstrap.sh
+++ b/bootstrap/generated-dists/ubuntu1804/bootstrap.sh
@@ -88,6 +88,7 @@ apt-get -y install \
     python-iso8601 \
     python-markdown \
     python-pexpect \
+    python3 \
     python3-crypto \
     python3-dbg \
     python3-dev \
diff --git a/bootstrap/generated-dists/ubuntu1804/packages.yml b/bootstrap/generated-dists/ubuntu1804/packages.yml
index 7d02be88ff7..07e0ab9c217 100644
--- a/bootstrap/generated-dists/ubuntu1804/packages.yml
+++ b/bootstrap/generated-dists/ubuntu1804/packages.yml
@@ -77,6 +77,7 @@ packages:
   - python-iso8601
   - python-markdown
   - python-pexpect
+  - python3
   - python3-crypto
   - python3-dbg
   - python3-dev
diff --git a/bootstrap/sha1sum.txt b/bootstrap/sha1sum.txt
index f4e6322c5b6..a5d74e48a7e 100644
--- a/bootstrap/sha1sum.txt
+++ b/bootstrap/sha1sum.txt
@@ -1 +1 @@
-2be76362af215af6842e884abd5246dd9b50c283
+93278680b4e7086c0bec11a58bc3533f9971c08e
diff --git a/source4/rpc_server/wscript_build b/source4/rpc_server/wscript_build
index a101846cdf2..019bd2026c1 100644
--- a/source4/rpc_server/wscript_build
+++ b/source4/rpc_server/wscript_build
@@ -119,7 +119,8 @@ bld.SAMBA_MODULE('dcerpc_lsarpc',
 	)
 
 
-if bld.CONFIG_SET('HAVE_GNUTLS_X509_CRT_SET_SUBJECT_UNIQUE_ID'):
+if (bld.CONFIG_SET('HAVE_GNUTLS_PRIVKEY_EXPORT_X509') and
+    bld.CONFIG_SET('HAVE_GNUTLS_X509_CRT_SET_SUBJECT_UNIQUE_ID')):
 	bld.SAMBA_MODULE('dcerpc_backupkey',
 		source='backupkey/dcesrv_backupkey.c ',
 		autoproto='backupkey/proto.h',
diff --git a/source4/torture/wscript_build b/source4/torture/wscript_build
index 8433d620b01..1ae7c29bdd8 100644
--- a/source4/torture/wscript_build
+++ b/source4/torture/wscript_build
@@ -83,7 +83,8 @@ bld.SAMBA_SUBSYSTEM('IREMOTEWINSPOOL_COMMON',
 
 torture_rpc_backupkey = ''
 if bld.AD_DC_BUILD_IS_ENABLED():
-    if bld.CONFIG_SET('HAVE_GNUTLS_X509_CRT_SET_SUBJECT_UNIQUE_ID'):
+    if (bld.CONFIG_SET('HAVE_GNUTLS_PRIVKEY_EXPORT_X509') and
+        bld.CONFIG_SET('HAVE_GNUTLS_X509_CRT_SET_SUBJECT_UNIQUE_ID')):
         torture_rpc_backupkey = 'rpc/backupkey.c'
     else:
         torture_rpc_backupkey = 'rpc/backupkey_heimdal.c'
diff --git a/wscript_configure_system_gnutls b/wscript_configure_system_gnutls
index 2e4dc126f3a..cc9a2b035a2 100644
--- a/wscript_configure_system_gnutls
+++ b/wscript_configure_system_gnutls
@@ -20,6 +20,9 @@ conf.CHECK_CFG(package='gnutls',
 # Define gnutls as a system library
 conf.SET_TARGET_TYPE('gnutls', 'SYSLIB')
 
+# Check for gnutls_privkey_export_x509 (>= 3.4.0) required by backupkey
+conf.CHECK_FUNCS_IN('gnutls_privkey_export_x509', 'gnutls')


diff --git a/bootstrap/config.py b/bootstrap/config.py
index 627b7e11397..6d3fb2e5c9c 100644
--- a/bootstrap/config.py
+++ b/bootstrap/config.py
@@ -136,6 +136,7 @@ PKGS = [
     ('python-dnspython', 'python-dns'),
     ('python-pexpect', ''),  # for wintest only
 
+    ('python3', 'python3'),
     ('python3-dev', 'python3-devel'),
     ('python3-dbg', ''),
     ('python3-iso8601', ''),
@@ -210,14 +211,18 @@ YUM_BOOTSTRAP = r"""
 {GENERATED_MARKER}
 set -xueo pipefail
 
-yum -y -q update
-yum -y -q install epel-release
-yum -y -q update
+yum update -y
+yum install -y epel-release
+yum update -y
 
-yum -y -q --verbose install \
+yum install -y \
     {pkgs}
 
 yum clean all
+
+if [ ! -f /usr/bin/python3 ]; then
+    ln -sf /usr/bin/python3.6 /usr/bin/python3
+fi
 """
 
 
@@ -427,7 +432,8 @@ RPM_DISTS = {
         'bootstrap': YUM_BOOTSTRAP,
         'replace': {
             'lsb-release': 'redhat-lsb',
-            'python3-devel': 'python34-devel',
+            'python3': 'python36',
+            'python3-devel': 'python36-devel',
             'python2-gpg': 'pygpgme',
             'python3-gpg': '',  # no python3-gpg yet
             '@development-tools': '"@Development Tools"',  # add quotes
@@ -449,10 +455,16 @@ RPM_DISTS = {
         'bootstrap': YUM_BOOTSTRAP,
         'replace': {
             'lsb-release': 'redhat-lsb',
-            'python3-devel': 'python34-devel',
+            'python3': 'python36',
+            'python3-crypto': 'python36-crypto',
+            'python3-devel': 'python36-devel',
+            'python3-dns': 'python36-dns',
+            'python3-gpg': 'python36-gpg',
+            'python3-iso8601' : 'python36-iso8601',
+            'python3-markdown': 'python36-markdown',
             # although python36-devel is available
             # after epel-release installed
             # however, all other python3 pkgs are still python34-ish
             'python2-gpg': 'pygpgme',
             'python3-gpg': '',  # no python3-gpg yet
             '@development-tools': '"@Development Tools"',  # add quotes
@@ -449,10 +455,16 @@ RPM_DISTS = {
             # although python36-devel is available
             # after epel-release installed
-            # however, all other python3 pkgs are still python34-ish
+            # however, all other python3 pkgs are still python36-ish
             'python2-gpg': 'pygpgme',
             'python3-gpg': '',  # no python3-gpg yet
-- 
Samba Shared Repository



More information about the samba-cvs mailing list